@@ -219,7 +219,7 @@ inline double glmmr::ModelOptim<modeltype>::log_likelihood() {
   ArrayXd xb(model.xb());
   
   if(model.weighted){
-    if(model.family.family==FamilyDistribution::gaussian){
+    if(model.family.family==Fam::gaussian){
 #pragma omp parallel for reduction (+:ll) collapse(2)
       for(int j=0; j<re.Zu().cols() ; j++){
         for(int i = 0; i<model.n(); i++){
@@ -284,7 +284,7 @@ inline dblvec glmmr::ModelOptim<modeltype>::get_start_values(bool beta, bool the
   } else {
     start = model.covariance.parameters_;
   }
-  if(var && (model.family.family==FamilyDistribution::gaussian||model.family.family==FamilyDistribution::gamma||model.family.family==FamilyDistribution::beta)){
+  if(var && (model.family.family==Fam::gaussian||model.family.family==Fam::gamma||model.family.family==Fam::beta)){
     start.push_back(model.data.var_par);
   }
   return start;
@@ -320,7 +320,7 @@ inline dblvec glmmr::ModelOptim<modeltype>::get_lower_values(bool beta, bool the
       lower.push_back(1e-6);
     }
   }
-  if(var && (model.family.family==FamilyDistribution::gaussian||model.family.family==FamilyDistribution::gamma||model.family.family==FamilyDistribution::beta)){
+  if(var && (model.family.family==Fam::gaussian||model.family.family==Fam::gamma||model.family.family==Fam::beta)){
     lower.push_back(0.0);
   }
   return lower;
@@ -343,7 +343,7 @@ inline dblvec glmmr::ModelOptim<modeltype>::get_upper_values(bool beta, bool the
       upper.push_back(R_PosInf);
     }
   }
-  if(var && (model.family.family==FamilyDistribution::gaussian||model.family.family==FamilyDistribution::gamma||model.family.family==FamilyDistribution::beta)){
+  if(var && (model.family.family==Fam::gaussian||model.family.family==Fam::gamma||model.family.family==Fam::beta)){
     upper.push_back(R_PosInf);
   }
   return upper;
@@ -351,7 +351,6 @@ inline dblvec glmmr::ModelOptim<modeltype>::get_upper_values(bool beta, bool the
 
 template<typename modeltype>
 inline void glmmr::ModelOptim<modeltype>::nr_beta(){
-  using enum FamilyDistribution;
   int niter = re.u(false).cols();
   MatrixXd zd = matrix.linpred();
   ArrayXd sigmas(niter);
@@ -365,16 +364,16 @@ inline void glmmr::ModelOptim<modeltype>::nr_beta(){
     MatrixXd Wu = MatrixXd::Zero(model.n(),niter);
     ArrayXd nvar_par(model.n());
     switch(model.family.family){
-      case gaussian:
+      case Fam::gaussian:
         nvar_par = model.data.variance;
         break;
-      case gamma:
+      case Fam::gamma:
         nvar_par = model.data.variance.inverse();
         break;
-      case beta:
+      case Fam::beta:
         nvar_par = (1+model.data.variance);
         break;
-      case binomial:
+      case Fam::binomial:
         nvar_par = model.data.variance.inverse();
         break;
       default:
@@ -387,7 +386,7 @@ inline void glmmr::ModelOptim<modeltype>::nr_beta(){
       w = ((w.array() *nvar_par).inverse() * model.data.weights).matrix();
       VectorXd zdu = glmmr::maths::mod_inv_func(zd.col(i), model.family.link);
       VectorXd dmu = glmmr::maths::detadmu(zd.col(i),model.family.link);
-      if(model.family.family == binomial){
+      if(model.family.family == Fam::binomial){
         zdu = zdu.cwiseProduct(model.data.variance.matrix());
         dmu = dmu.cwiseProduct(model.data.variance.inverse().matrix());
       }
@@ -416,7 +415,7 @@ inline void glmmr::ModelOptim<modeltype>::laplace_nr_beta_u(){
   MatrixXd infomat = matrix.observed_information_matrix();
   infomat = infomat.llt().solve(MatrixXd::Identity(model.linear_predictor.P()+model.covariance.Q(),model.linear_predictor.P()+model.covariance.Q()));
   VectorXd zdu =  glmmr::maths::mod_inv_func(zd, model.family.link);
-  if(model.family.family == FamilyDistribution::binomial){
+  if(model.family.family == Fam::binomial){
     zdu = zdu.cwiseProduct(model.data.variance.matrix());
     dmu = dmu.cwiseProduct(model.data.variance.inverse().matrix());
   }
@@ -451,7 +450,7 @@ inline void glmmr::ModelOptim<modeltype>::update_var_par(const ArrayXd& v){
 
 template<typename modeltype>
 inline void glmmr::ModelOptim<modeltype>::calculate_var_par(){
-  if(model.family.family==FamilyDistribution::gaussian){
+  if(model.family.family==Fam::gaussian){
     // revise this for beta and Gamma re residuals
     int niter = re.u(false).cols();
     ArrayXd sigmas(niter);
@@ -632,7 +631,7 @@ inline double glmmr::ModelOptim<modeltype>::F_likelihood::operator()(const dblve
   dblvec theta(last1,last2);
   M.update_beta(beta);
   M.update_theta(theta);
-  if(M.model.family.family==FamilyDistribution::gaussian || M.model.family.family==FamilyDistribution::gamma || M.model.family.family==FamilyDistribution::beta)M.update_var_par(par[M.model.linear_predictor.P()+G]);
+  if(M.model.family.family==Fam::gaussian || M.model.family.family==Fam::gamma || M.model.family.family==Fam::beta)M.update_var_par(par[M.model.linear_predictor.P()+G]);
   ll = M.full_log_likelihood();
   if(importance){
     return -1.0 * log(exp(ll)/ exp(denomD));
@@ -652,7 +651,7 @@ inline double glmmr::ModelOptim<modeltype>::LA_likelihood::operator()(const dblv
   M.update_u(v);
   logl = v.col(0).transpose()*v.col(0);
   ll = M.log_likelihood();
-  if(M.model.family.family!=FamilyDistribution::gaussian){
+  if(M.model.family.family!=Fam::gaussian){
     M.matrix.W.update();
     LZWZL = M.model.covariance.LZWZL(M.matrix.W.W());
     LZWdet = glmmr::maths::logdet(LZWZL);
